@@ -1,8 +1,6 @@
 """Helpers to work with Beancount entry objects."""
-import json
 
-from beancount.core.data import Posting
-from beancount.core.data import Transaction
+from beancount.core.data import Posting, Transaction
 
 
 def update_postings(transaction, accounts):
@@ -30,12 +28,6 @@ def set_entry_attribute(entry, attribute, value, overwrite=False):
     return entry
 
 
-def add_suggestions_to_entry(entry, suggestions, key):
-    """Adds a list of suggestions to an entry under entry.meta[key]."""
-    entry.meta[key] = json.dumps(suggestions)
-    return entry
-
-
 def merge_non_transaction_entries(imported_entries, enhanced_transactions):
     """Merge modified transactions back into a list of entries."""
     enhanced_entries = []
